km3modules\.k40\.load\_k40\_coincidences\_from\_rootfile
========================================================

.. currentmodule:: km3modules.k40

.. autofunction:: load_k40_coincidences_from_rootfile